Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3324)

Unified Diff: chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestCanMakePaymentQueryNoCardTest.java

Issue 2545523004: Rename canMakeActivePayment to canMakePayment (Closed)
Patch Set: Rebase Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestCanMakePaymentQueryNoCardTest.java
diff --git a/chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestActivePaymentQueryNoCardTest.java b/chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestCanMakePaymentQueryNoCardTest.java
similarity index 79%
rename from chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestActivePaymentQueryNoCardTest.java
rename to chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestCanMakePaymentQueryNoCardTest.java
index ad6c08fa141d5bfbbfe7ec1018651480609d74be..c5a65d7e9e751dccfa95c5c331b7216616842cd4 100644
--- a/chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestActivePaymentQueryNoCardTest.java
+++ b/chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestCanMakePaymentQueryNoCardTest.java
@@ -16,20 +16,20 @@ import java.util.concurrent.ExecutionException;
import java.util.concurrent.TimeoutException;
/**
- * A payment integration test for checking whether user can make active payment via either payment
+ * A payment integration test for checking whether user can make a payment via either payment
* app or a credit card. This user does not have a complete credit card on file.
*/
-@CommandLineFlags.Add("enable-blink-features=CanMakeActivePayment")
-public class PaymentRequestActivePaymentQueryNoCardTest extends PaymentRequestTestBase {
- public PaymentRequestActivePaymentQueryNoCardTest() {
- super("payment_request_active_payment_query_test.html");
+@CommandLineFlags.Add("enable-blink-features=CanMakePayment")
+public class PaymentRequestCanMakePaymentQueryNoCardTest extends PaymentRequestTestBase {
+ public PaymentRequestCanMakePaymentQueryNoCardTest() {
+ super("payment_request_can_make_payment_query_test.html");
}
@Override
public void onMainActivityStarted() throws InterruptedException, ExecutionException,
TimeoutException {
// The user has an incomplete credit card on file. This is not sufficient for
// canMakeActivePayment() to return true.
new AutofillTestHelper().setCreditCard(new CreditCard("", "https://example.com", true, true,
"Jon Doe", "4111111111111111", "1111", "12", "2050", "visa", R.drawable.pr_visa,
"" /* billingAddressId */, "" /* serverId */));
@@ -39,7 +39,7 @@ public class PaymentRequestActivePaymentQueryNoCardTest extends PaymentRequestTe
@Feature({"Payments"})
public void testNoBobPayInstalled() throws InterruptedException, ExecutionException,
TimeoutException {
- openPageAndClickBuyAndWait(mActivePaymentQueryResponded);
+ openPageAndClickBuyAndWait(mCanMakePaymentQueryResponded);
expectResultContains(new String[]{"false"});
}
@@ -48,7 +48,7 @@ public class PaymentRequestActivePaymentQueryNoCardTest extends PaymentRequestTe
public void testNoInstrumentsInFastBobPay() throws InterruptedException, ExecutionException,
TimeoutException {
installPaymentApp(NO_INSTRUMENTS, IMMEDIATE_RESPONSE);
- openPageAndClickBuyAndWait(mActivePaymentQueryResponded);
+ openPageAndClickBuyAndWait(mCanMakePaymentQueryResponded);
expectResultContains(new String[]{"false"});
}
@@ -57,7 +57,7 @@ public class PaymentRequestActivePaymentQueryNoCardTest extends PaymentRequestTe
public void testNoInstrumentsInSlowBobPay() throws InterruptedException, ExecutionException,
TimeoutException {
installPaymentApp(NO_INSTRUMENTS, DELAYED_RESPONSE);
- openPageAndClickBuyAndWait(mActivePaymentQueryResponded);
+ openPageAndClickBuyAndWait(mCanMakePaymentQueryResponded);
expectResultContains(new String[]{"false"});
}
@@ -66,7 +66,7 @@ public class PaymentRequestActivePaymentQueryNoCardTest extends PaymentRequestTe
public void testPayViaFastBobPay() throws InterruptedException, ExecutionException,
TimeoutException {
installPaymentApp(HAVE_INSTRUMENTS, IMMEDIATE_RESPONSE);
- openPageAndClickBuyAndWait(mActivePaymentQueryResponded);
+ openPageAndClickBuyAndWait(mCanMakePaymentQueryResponded);
expectResultContains(new String[]{"true"});
}
@@ -75,7 +75,7 @@ public class PaymentRequestActivePaymentQueryNoCardTest extends PaymentRequestTe
public void testPayViaSlowBobPay() throws InterruptedException, ExecutionException,
TimeoutException {
installPaymentApp(HAVE_INSTRUMENTS, DELAYED_RESPONSE);
- openPageAndClickBuyAndWait(mActivePaymentQueryResponded);
+ openPageAndClickBuyAndWait(mCanMakePaymentQueryResponded);
expectResultContains(new String[]{"true"});
}
}
@@ -16,20 +16,20 @@ import java.util.concurrent.ExecutionException;
TimeoutException {
// The user has an incomplete credit card on file. This is not sufficient for
- // canMakeActivePayment() to return true.
+ // canMakePayment() to return true.
new AutofillTestHelper().setCreditCard(new CreditCard("", "https://example.com", true, true,
"Jon Doe", "4111111111111111", "1111", "12", "2050", "visa", R.drawable.pr_visa,

Powered by Google App Engine
This is Rietveld 408576698